package org.kde.koala;
import org.kde.qt.*;


/** {@link KConfig} emits these signals */
public interface KConfigSignals {
	void destroyed( QObject obj );
}

